==> haskell-vector-hashtables-0.1.2.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-hashtables
version:              0.1.2.0
visibility:           public
id:                   vector-hashtables-0.1.2.0-AYjrDi0Vv65H8rIIbTTFEk
key:                  vector-hashtables-0.1.2.0-AYjrDi0Vv65H8rIIbTTFEk
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  80684fd750fd471a0fcc93e99734119e
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-hashtables-0.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-hashtables-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.0-AYjrDi0Vv65H8rIIbTTFEk
depends:
    base-4.16.4.0 hashable-1.4.4.0-DtL5AH6y1if92iaAq0qoKj
    primitive-0.7.4.0-1hjisjTIkm1Ju7TlHVggBl
    vector-0.13.1.0-1Hbj4hORR7KGMeSpv0BhQN

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-hashtables-0.1.2.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-hashtables
version:              0.1.2.0
visibility:           public
id:                   vector-hashtables-0.1.2.0-HdrJtk0O0eMB6d22VPJsLc
key:                  vector-hashtables-0.1.2.0-HdrJtk0O0eMB6d22VPJsLc
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  298e7cb94ab54da949d7052f506f85a1
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-hashtables-0.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-hashtables-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.0-HdrJtk0O0eMB6d22VPJsLc
depends:
    base-4.16.4.0 hashable-1.4.4.0-BrYG523VafVKM4yDK0K7G3
    primitive-0.7.4.0-I9XTAmFqErC1hXdXvvNzkS
    vector-0.13.1.0-Gf2urNiIAD32gZDiWE6SSZ

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
